@@ -24,7 +24,7 @@ test_that("occ_download input parsing", {
   expect_equal(aa$predicate$key[1], "HAS_COORDINATE")
   expect_equal(aa$predicate$value[1], "TRUE")
 
-  aa <- parse_occd(user, email, type, 'geometry=POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))')
+  aa <- parse_occd(user, email, type, 'geometry = POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))')
   expect_is(aa, "list")
   expect_is(aa$predicate$type, "character")
   expect_is(aa$predicate$type, "scalar")
@@ -33,7 +33,9 @@ test_that("occ_download input parsing", {
   expect_equal(aa$predicate$value[1], "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))")
 
   aa <- parse_occd(user, email, type,
-               'taxonKey = 7228682', 'hasCoordinate = TRUE', 'hasGeospatialIssue = FALSE',
+               'taxonKey = 7228682',
+               'hasCoordinate = TRUE',
+               'hasGeospatialIssue = FALSE',
                'geometry=POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))')
   expect_is(aa, "list")
   expect_named(aa, c("creator", "notification_address", "predicate"))
