@@ -2,89 +2,84 @@ context("occ_data")
 
 key <- 3118771
 
+# Search by key
 test_that("returns the correct class", {
   vcr::use_cassette("occ_data", {
-
-    # Search by key
-    tt <- occ_data(taxonKey=key, limit=2)
-    uu <- occ_data(taxonKey=key, limit=20)
-    vv <- occ_data(taxonKey=key)
-
-    expect_is(tt$meta, "list")
-    expect_is(tt$meta$endOfRecords, "logical")
-    expect_is(tt$data, "data.frame")
-    expect_is(tt$data$name, "character")
-    expect_is(vv, "gbif_data")
-    # meta no longer has gbif class
-    expect_equal(length(class(vv)), 1)
-
-    expect_equal(tt$meta$limit, 2)
-    # occ_data doesn't have hierarchy slot
-    expect_null(tt$hierarchy)
-    # occ_data doesn't have media slot
-    expect_null(tt$media)
-
-    expect_equal(uu$data[1,1]$name, "Encelia californica")
-    expect_equal(uu$meta$limit, 20)
-    expect_null(vv$limit)
-
-    expect_equal(length(tt), 2)
-    expect_equal(length(tt$meta), 4)
+    tt <- occ_data(taxonKey = key, limit=2)
+    uu <- occ_data(taxonKey = key, limit=20)
+    vv <- occ_data(taxonKey = key)
   })
+
+  expect_is(tt$meta, "list")
+  expect_is(tt$meta$endOfRecords, "logical")
+  expect_is(tt$data, "data.frame")
+  expect_is(tt$data$name, "character")
+  expect_is(vv, "gbif_data")
+  # meta no longer has gbif class
+  expect_equal(length(class(vv)), 1)
+
+  expect_equal(tt$meta$limit, 2)
+  # occ_data doesn't have hierarchy slot
+  expect_null(tt$hierarchy)
+  # occ_data doesn't have media slot
+  expect_null(tt$media)
+
+  expect_equal(uu$data$species[1], "Encelia californica")
+  expect_equal(uu$meta$limit, 20)
+  expect_null(vv$limit)
+
+  expect_equal(length(tt), 2)
+  expect_equal(length(tt$meta), 4)
 })
 
 # Search by dataset key
 test_that("returns the correct dimensions", {
   vcr::use_cassette("occ_data_datasetkey", {
-
     out <- occ_data(datasetKey='7b5d6a48-f762-11e1-a439-00145eb45e9a')
-
-    # returns the correct class
-    expect_is(out, "gbif_data")
-    expect_is(out$meta, "list")
-    expect_is(out$data, "data.frame")
-    # dimensions
-    expect_gt(NROW(out$data), 10)
   })
+
+  # returns the correct class
+  expect_is(out, "gbif_data")
+  expect_is(out$meta, "list")
+  expect_is(out$data, "data.frame")
+  # dimensions
+  expect_gt(NROW(out$data), 10)
 })
 
 ## Search by catalog number
 test_that("returns the correct class", {
   vcr::use_cassette("occ_data_catalog_number", {
-
     out <- occ_data(catalogNumber = '6845144')
-
-    expect_is(out, "gbif_data")
-    expect_is(out$meta, "list")
-    expect_is(out$data, "data.frame")
-
-    # returns the correct value
-    expect_true(out$meta$endOfRecords)
-
-    # returns the correct dimensions
-    expect_equal(length(out), 2)
   })
+
+  expect_is(out, "gbif_data")
+  expect_is(out$meta, "list")
+  expect_is(out$data, "data.frame")
+
+  # returns the correct value
+  expect_true(out$meta$endOfRecords)
+
+  # returns the correct dimensions
+  expect_equal(length(out), 2)
 })
 
 ######### Get occurrences for a particular eventDate
 test_that("dates work correctly", {
   vcr::use_cassette("occ_data_event_date", {
+    a <- occ_data(taxonKey = 3189815, year="2013")
+    b <- occ_data(taxonKey = 3189815, month="6")
+    expect_is(occ_data(taxonKey = key, year="1990,1991"), "gbif_data")
+  }, preserve_exact_body_bytes = TRUE)
 
-    a <- occ_data(taxonKey=3189815, year="2013")
-    b <- occ_data(taxonKey=3189815, month="6")
+  expect_equal(a$data$year[1], 2013)
+  expect_equal(b$data$month[1], 6)
 
-    expect_equal(a$data$year[1], 2013)
-    expect_equal(b$data$month[1], 6)
-
-    expect_is(occ_data(taxonKey=key, year="1990,1991"), "gbif_data")
-  })
 })
 
 test_that("make sure things that should throw errors do", {
   vcr::use_cassette("occ_data_fails_well", {
-
     # not allowed to do a range query on many variables, including contintent
-    expect_error(occ_data(taxonKey=3189815, continent = 'asia,oceania'))
+    expect_error(occ_data(taxonKey = 3189815, continent = 'asia,oceania'))
     # can't pass the wrong value to latitude
     expect_error(occ_data(decimalLatitude = 334))
   })
@@ -92,91 +87,95 @@ test_that("make sure things that should throw errors do", {
 
 ######### Get occurrences based on depth
 test_that("returns the correct stuff", {
+  key <- 7595433
   vcr::use_cassette("occ_data_depth", {
-
-    key <- name_backbone(name='Salmo salar', kingdom='animals')$speciesKey
-    expect_is(occ_data(taxonKey=key, depth="5"), "gbif_data")
-    expect_is(occ_data(taxonKey=key, depth=5), "gbif_data")
+    expect_is(occ_data(taxonKey = key, depth="5"), "gbif_data")
+    expect_is(occ_data(taxonKey = key, depth=5), "gbif_data")
     # does range search correctly - THROWS ERROR NOW, BUT SHOULD WORK
-    expect_error(occ_data(taxonKey=key, depth="5-10"))
+    expect_error(occ_data(taxonKey = key, depth="5-10"))
   })
 })
 
 ######### Get occurrences based on elevation
 test_that("returns the correct dimensions", {
+  key <- 2435099
   vcr::use_cassette("occ_data_elevation", {
-
-    key <- name_backbone(name='Puma concolor', kingdom='animals')$speciesKey
-    res <- occ_data(taxonKey=key, elevation=1000, hasCoordinate=TRUE)
-    expect_equal(res$data$elevation[1], 1000)
+    res <- occ_data(taxonKey = key, elevation=1000, hasCoordinate=TRUE)
   })
+  expect_equal(res$data$elevation[1], 1000)
 })
 
 # test that looping is working correctly
 test_that("looping works correctly", {
   vcr::use_cassette("occ_data_looping", {
-
     it <- seq(from = 0, to = 500, by = 250)
     out <- list()
     for (i in seq_along(it)) {
       occdata <- occ_data(taxonKey = 3118771, limit = 250, start = it[[i]])
       out[[i]] <- occdata$data
     }
-
-    expect_equal(unique(sapply(out, function(x) class(x)[1])), "tbl_df")
   }, preserve_exact_body_bytes = TRUE)
+
+  expect_equal(unique(sapply(out, function(x) class(x)[1])), "tbl_df")
 })
 
 ######### scientificName usage works correctly
 test_that("scientificName basic use works - no synonyms", {
   vcr::use_cassette("occ_data_scientificname", {
-
     # with synonyms
     bb <- suppressMessages(occ_data(scientificName = 'Pulsatilla patens', limit = 2))
-    expect_equal(attr(bb, "args")$scientificName, "Pulsatilla patens")
-    expect_equal(bb$data$name[1], "Pulsatilla patens")
-
     # Genus is a synonym - subspecies rank input
     cc <- suppressMessages(occ_data(scientificName = 'Corynorhinus townsendii ingens', limit = 2))
-    expect_is(cc, "gbif_data")
-    expect_is(cc$data, "data.frame")
-    expect_equal(attr(cc, "args")$scientificName, "Corynorhinus townsendii ingens")
-    expect_equal(cc$data$name[1], "Corynorhinus townsendii")
-
     # Genus is a synonym - species rank input
     dd <- suppressMessages(occ_data(scientificName = 'Corynorhinus townsendii', limit = 2))
-    expect_is(dd, "gbif_data")
-    expect_is(dd$data, "data.frame")
-    expect_equal(NROW(dd$data), 2)
-    expect_equal(attr(dd, "args")$scientificName, "Corynorhinus townsendii")
-    expect_equal(dd$data$name[1], "Corynorhinus townsendii")
-
     # specific epithet is the synonym - subspecies rank input
-    ee <- suppressMessages(occ_data(scientificName = "Myotis septentrionalis septentrionalis", limit = 2))
-    expect_is(ee, "gbif_data")
-    expect_null(suppressWarnings(ee$data))
-    expect_equal(attr(ee, "args")$scientificName, "Myotis septentrionalis septentrionalis")
-
+    # ee <- suppressMessages(occ_data(scientificName = "Myotis septentrionalis septentrionalis", limit = 2))
     # above with subspecific name removed, gives result
     ff <- suppressMessages(occ_data(scientificName = "Myotis septentrionalis", limit = 2))
-    expect_is(ff, "gbif_data")
-    expect_equal(NROW(ff$data), 2)
-    expect_equal(attr(ff, "args")$scientificName, "Myotis septentrionalis")
-    expect_equal(ff$data$name[1], "Myotis septentrionalis")
-
     # Genus is a synonym - species rank input - species not found, so Genus rank given back
-    gg <- suppressMessages(occ_data(scientificName = 'Parastrellus hesperus', limit = 2))
-    expect_is(gg, "gbif_data")
-    expect_is(gg$data, "data.frame")
-    ## above not found, but found after using name_lookup to find a match, genus wrong in this case
-    # name_lookup(query = 'Parastrellus hesperus')
     hh <- suppressMessages(occ_data(scientificName = 'Pipistrellus hesperus', limit = 2))
-    expect_is(hh, "gbif_data")
-    expect_is(hh$data, "data.frame")
-    expect_equal(attr(hh, "args")$scientificName, "Pipistrellus hesperus")
-    expect_equal(hh$data$name[1], "Parastrellus hesperus")
-
   }, preserve_exact_body_bytes = TRUE)
+
+  expect_equal(attr(bb, "args")$scientificName, "Pulsatilla patens")
+  expect_equal(bb$data$species[1], "Pulsatilla patens")
+  expect_equal(bb$data$scientificName[1],
+    "Anemone patens subsp. multifida (Pritzel) Hultén")
+  
+  expect_is(cc, "gbif_data")
+  expect_is(cc$data, "data.frame")
+  expect_equal(attr(cc, "args")$scientificName,
+    "Corynorhinus townsendii ingens")
+  expect_equal(cc$data$species[1], "Corynorhinus townsendii")
+  expect_equal(cc$data$scientificName[1],
+    "Corynorhinus townsendii ingens Handley, 1955")
+
+  expect_is(dd, "gbif_data")
+  expect_is(dd$data, "data.frame")
+  expect_equal(NROW(dd$data), 2)
+  expect_equal(attr(dd, "args")$scientificName, "Corynorhinus townsendii")
+  expect_equal(dd$data$species[1], "Corynorhinus townsendii")
+  expect_equal(dd$data$scientificName[1],
+    "Corynorhinus townsendii (Cooper, 1837)")
+
+  # expect_is(ee, "gbif_data")
+  # expect_null(suppressWarnings(ee$data))
+  # expect_equal(attr(ee, "args")$scientificName, "Myotis septentrionalis septentrionalis")
+
+  expect_is(ff, "gbif_data")
+  expect_equal(NROW(ff$data), 2)
+  expect_equal(attr(ff, "args")$scientificName, "Myotis septentrionalis")
+  expect_equal(ff$data$species[1], "Myotis septentrionalis")
+  expect_equal(ff$data$scientificName[1],
+    "Myotis septentrionalis (Trouessart, 1897)")
+  
+  expect_is(hh, "gbif_data")
+  expect_is(hh$data, "data.frame")
+  expect_equal(attr(hh, "args")$scientificName, "Pipistrellus hesperus")
+  expect_equal(hh$data$species[1], "Parastrellus hesperus")
+  expect_equal(hh$data$scientificName[1],
+    "Pipistrellus hesperus (H.Allen, 1864)")
+  expect_equal(hh$data$acceptedScientificName[1],
+    "Parastrellus hesperus (H.Allen, 1864)")
 })
 
 ######### geometry inputs work as expected
@@ -192,7 +191,7 @@ test_that("geometry inputs work as expected", {
 
     # with a taxon key
     key <- 3189815
-    bb <- occ_data(taxonKey=key, geometry='POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))',
+    bb <- occ_data(taxonKey = key, geometry='POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))',
                      limit=20)
     expect_is(bb, "gbif_data")
     expect_is(unclass(bb), "list")
@@ -294,7 +293,6 @@ test_that("geometry inputs work as expected", {
 ######### spell check works
 test_that("spell check param works", {
   vcr::use_cassette("occ_data_spellcheck", {
-
     # as normal
     expect_is(
       occ_data(search = "kingfisher", limit=1, spellCheck = TRUE),
@@ -312,30 +310,26 @@ test_that("spell check param works", {
       occ_data(search = "helir", limit=20, spellCheck = TRUE),
       "spelling bad - suggestions"
     )
-
   })
 })
 
-
 # many args
 test_that("works with parameters that allow many inputs", {
   vcr::use_cassette("occ_data_args_with_many_inputs", {
-
     ## separate requests: use a vector of strings
     aa <- occ_data(recordedBy=c("smith","BJ Stacey"), limit=3)
     ## one request, many instances of same parameter: use semi-colon sep. string
     bb <- occ_data(recordedBy="smith;BJ Stacey", limit=3)
-
-    expect_is(aa, "gbif_data")
-    expect_is(bb, "gbif_data")
-
-    expect_named(aa, c('smith', 'BJ Stacey'))
-    expect_named(bb, c('meta', 'data'))
-
-    expect_equal(unique(tolower(aa[[1]]$data$recordedBy)), "smith")
-    expect_equal(unique(tolower(aa[[2]]$data$recordedBy)), "bj stacey")
-
-    expect_true(unique(tolower(bb$data$recordedBy)) %in% c('smith', 'bj stacey'))
-
   })
+  
+  expect_is(aa, "gbif_data")
+  expect_is(bb, "gbif_data")
+
+  expect_named(aa, c('smith', 'BJ Stacey'))
+  expect_named(bb, c('meta', 'data'))
+
+  expect_equal(unique(tolower(aa[[1]]$data$recordedBy)), "smith")
+  expect_equal(unique(tolower(aa[[2]]$data$recordedBy)), "bj stacey")
+
+  expect_true(unique(tolower(bb$data$recordedBy)) %in% c('smith', 'bj stacey'))
 })
